@@ -87,6 +87,6 @@ class AsyncResult:
         Should be called after the `action` has been updated with the result of `refresh`.
         """
         message = self._get_message()
-        if message not in self._seen:
+        if message and message not in self._seen:
             self.progress.write(message)
             self._seen.add(message)
