@@ -10,7 +10,7 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
-# pylint:disable=missing-module-docstring
+# pylint:disable=missing-module-docstring, too-few-public-methods
 
 import re
 import shutil
@@ -102,7 +102,7 @@ def docstring_section(title: str) -> Callable:
     return customized_decorator
 
 
-class BaseDoc:  # pylint:disable=too-few-public-methods
+class BaseDoc:
     """The base class for all docstring pieces.
 
     Subclasses should implement the __str__ method.
@@ -165,7 +165,7 @@ class Docstring(BaseDoc):  # pylint:disable=too-few-public-methods
         return "\n\n".join(sections)
 
 
-@attr.s(auto_attribs=True)  # pylint:disable=too-few-public-methods
+@attr.s(auto_attribs=True)
 class ClassAttribute(BaseDoc):
     """Describes a class attribute.
 
@@ -219,7 +219,7 @@ class ClassDocstring(Docstring):
         return self.attrs
 
 
-@attr.s(auto_attribs=True)  # pylint:disable=too-few-public-methods
+@attr.s(auto_attribs=True)
 class FunctionArgument(BaseDoc):
     """Describes an argument to a function.
 
@@ -287,7 +287,7 @@ class PossibleException(BaseDoc):
         return result
 
 
-@attr.s(auto_attribs=True)  # pylint:disable=too-few-public-methods
+@attr.s(auto_attribs=True)
 class Returns(BaseDoc):
     """Describes the object returned from a function.
 
@@ -323,7 +323,7 @@ class Returns(BaseDoc):
         return result
 
 
-@attr.s(auto_attribs=True)  # pylint:disable=too-few-public-methods
+@attr.s(auto_attribs=True)
 class WarningsType(BaseDoc):
     """Describes the warnings section of NumpyDoc."""
 
@@ -333,7 +333,7 @@ class WarningsType(BaseDoc):
         return self.warnings
 
 
-@attr.s(auto_attribs=True)  # pylint:disable=too-few-public-methods
+@attr.s(auto_attribs=True)
 class SeeAlsoType(BaseDoc):
     """Describes the see also section of NumpyDoc."""
 
@@ -343,7 +343,7 @@ class SeeAlsoType(BaseDoc):
         return self.see_also
 
 
-@attr.s(auto_attribs=True)  # pylint:disable=too-few-public-methods
+@attr.s(auto_attribs=True)
 class NotesType(BaseDoc):
     """Describes the notes section of NumpyDoc."""
 
@@ -353,7 +353,7 @@ class NotesType(BaseDoc):
         return self.notes
 
 
-@attr.s(auto_attribs=True)  # pylint:disable=too-few-public-methods
+@attr.s(auto_attribs=True)
 class ReferencesType(BaseDoc):
     """Describes the references section of NumpyDoc."""
 
@@ -365,7 +365,7 @@ class ReferencesType(BaseDoc):
         return re.sub(reference_link_regex, r".. [\1]", self.references)
 
 
-@attr.s(auto_attribs=True)  # pylint:disable=too-few-public-methods
+@attr.s(auto_attribs=True)
 class ExamplesType(BaseDoc):
     """Describes the examples section of NumpyDoc."""
 
