@@ -15,7 +15,6 @@ import logging
 import re
 from functools import wraps
 from typing import (
-    Any,
     Callable,
     Optional,
     Union,
@@ -31,7 +30,6 @@ from graphql import (
 from graphql.pyutils.undefined import UndefinedType
 from packaging import version
 from qctrlcommons.exceptions import QctrlException
-from qctrlcommons.utils import get_nested_value
 from requests import codes
 from requests.exceptions import HTTPError
 
@@ -58,93 +56,6 @@ class VersionError(QctrlException):
     """Raised when QCTRL client version is incompatible with the API."""
 
 
-def separate_list(source: list, func) -> tuple:
-    """Returns two lists. First list will only include items which have a non-
-    zero result when calling fn; second list will be every other item in the
-    source.
-
-    Parameters
-    ----------
-    source: list
-
-    func
-
-
-    Returns
-    -------
-    tuple
-        two list one is matched the other one is not matched.
-    """
-    matched = []
-    unmatched = []
-
-    for item in source:
-        if func(item):
-            matched.append(item)
-        else:
-            unmatched.append(item)
-
-    return matched, unmatched
-
-
-def get_resource_schema(schema: dict, resource_name: str) -> dict:
-    """Given the API schema, returns the schema for the given resource (if
-    exists).
-
-    Parameters
-    ----------
-    schema: dict
-        api schema.
-    resource_name: str
-        resource model.
-
-    Returns
-    -------
-    dict
-        nested value in the schema.
-    """
-    return get_nested_value(schema, "components.schemas.{}".format(resource_name), {})
-
-
-def normalize_encoded_field_name(
-    name: str = None, many: list = None, dict_keys: dict = None
-) -> Any:
-    """A function to normalize the field name based on the passing data type
-    (str, list or dict)
-
-    Parameters
-    ----------
-    name: str
-         field name. (Default value = None)
-    many: list
-         list field. (Default value = None)
-    dict_keys: dict
-         dict field. (Default value = None)
-
-    Returns
-    -------
-    Any
-        normalized field name.
-    """
-    pattern = re.compile("_encoded$")
-
-    if name:
-        return pattern.sub("", name)
-
-    if many:
-        return [normalize_encoded_field_name(x) for x in many]
-
-    if dict_keys:
-        result_dict_keys = {}
-        for key, value in dict_keys.items():
-            new_key = normalize_encoded_field_name(key)
-            result_dict_keys.update({new_key: value})
-
-        return result_dict_keys
-
-    return None
-
-
 def _is_undefined(value: any) -> bool:
     """Checks if a GraphQL value is of Undefined type.
 
